@@ -27,7 +27,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.3)
 # Project  : Official Cedar Backup Extensions
-# Revision : $Id: mbox.py 1104 2007-02-17 16:51:19Z pronovic $
+# Revision : $Id: mbox.py 1210 2007-07-05 03:04:54Z pronovic $
 # Purpose  : Provides an extension to back up mbox email files.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -105,7 +105,7 @@ from CedarBackup2.xmlutil import isElement, readChildren, readFirstChild, readSt
 from CedarBackup2.config import VALID_COLLECT_MODES, VALID_COMPRESS_MODES
 from CedarBackup2.util import isStartOfWeek, buildNormalizedPath
 from CedarBackup2.util import resolveCommand, executeCommand
-from CedarBackup2.util import ObjectTypeList, UnorderedList, encodePath, changeOwnership
+from CedarBackup2.util import ObjectTypeList, UnorderedList, RegexList, encodePath, changeOwnership
 
 
 ########################################################################
@@ -428,7 +428,7 @@ class MboxDir(object):
       else:
          try:
             saved = self._excludePatterns
-            self._excludePatterns = UnorderedList()
+            self._excludePatterns = RegexList()
             self._excludePatterns.extend(value)
          except Exception, e:
             self._excludePatterns = saved
