@@ -27,7 +27,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.3)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: peer.py 956 2006-05-26 23:05:12Z pronovic $
+# Revision : $Id: peer.py 1212 2007-07-10 03:08:39Z pronovic $
 # Purpose  : Provides backup peer-related objects.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -56,7 +56,6 @@ Provides backup peer-related objects and utility functions.
 import os
 import logging
 import shutil
-import tempfile
 import sets
 import re
 
@@ -438,7 +437,7 @@ class RemotePeer(object):
       Initializes a remote backup peer.
 
       @note: If provided, the rcp command will eventually be parsed into a list
-      of strings suitable for passing to L{popen2.Popen4} in order to avoid
+      of strings suitable for passing to C{popen2.Popen4} in order to avoid
       security holes related to shell interpolation.   This parsing will be
       done by the L{util.splitCommandLine} function.  See the documentation for
       that function for some important notes about its limitations.
@@ -735,10 +734,6 @@ class RemotePeer(object):
       @note: If you have user/group as strings, call the L{util.getUidGid} function
       to get the associated uid/gid as an ownership tuple.
 
-      @note: This method's behavior is UNIX-specific.  It depends on the
-      ability of L{tempfile.NamedTemporaryFile} to create files that can be
-      opened more than once.
-
       @param stageIndicator: Name of the indicator file to write
       @type stageIndicator: String representing name of a file in the collect directory
 
@@ -747,7 +742,6 @@ class RemotePeer(object):
       @raise OSError: If there is an OS error creating or changing permissions on the file
       """
       stageIndicator = encodePath(stageIndicator)
-      sourceFile = tempfile.NamedTemporaryFile(dir=self.workingDir)
       if stageIndicator is None:
          sourceFile = os.path.join(self.workingDir, DEF_STAGE_INDICATOR)
          targetFile = os.path.join(self.collectDir, DEF_STAGE_INDICATOR)
@@ -776,7 +770,7 @@ class RemotePeer(object):
       Returns the contents of a directory in terms of a Set.
       
       The directory's contents are read as a L{FilesystemList} containing only
-      files, and then the list is converted into a L{sets.Set} object for later
+      files, and then the list is converted into a C{sets.Set} object for later
       use.
 
       @param path: Directory path to get contents for
