@@ -11,7 +11,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.3)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: release.py 1194 2007-03-30 01:57:33Z pronovic $
+# Revision : $Id: release.py 1233 2007-09-20 03:07:42Z pronovic $
 # Purpose  : Provides location to maintain release information.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -34,7 +34,7 @@ Provides location to maintain version information.
 AUTHOR      = "Kenneth J. Pronovici"
 EMAIL       = "pronovic@ieee.org"
 COPYRIGHT   = "2004-2007"
-VERSION     = "2.13.1"
-DATE        = "29 Mar 2007"
+VERSION     = "2.14.0"
+DATE        = "19 Sep 2007"
 URL         = "http://cedar-solutions.com/software/cedar-backup"
 
