@@ -27,7 +27,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.3)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: testutil.py 1185 2007-03-25 19:04:50Z pronovic $
+# Revision : $Id: testutil.py 1232 2007-09-20 03:07:07Z pronovic $
 # Purpose  : Provides unit-testing utilities.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -75,7 +75,7 @@ import platform
 import logging
 from StringIO import StringIO
 
-from CedarBackup2.util import encodePath
+from CedarBackup2.util import encodePath, executeCommand
 
 
 ########################################################################
@@ -318,7 +318,7 @@ def failUnlessAssignRaises(testCase, exception, object, property, value):
    @param property: Name of the property, as a string.
    @param value: Value that is to be assigned to the property.
 
-   @see: L{unittest.TestCase.failUnlessRaises}
+   @see: C{unittest.TestCase.failUnlessRaises}
    """
    missed = False
    instead = None
@@ -467,3 +467,18 @@ def runningAsRoot():
       return os.geteuid() == 0
 
 
+##############################
+# availableLocales() function
+##############################
+
+def availableLocales():
+   """
+   Returns a list of available locales on the system
+   @return: List of string locale names
+   """
+   locales = []
+   output = executeCommand(["locale"], [ "-a", ], returnOutput=True, ignoreStderr=True)[1]
+   for line in output:
+      locales.append(line.rstrip())
+   return locales
+
