@@ -30,7 +30,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.3)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: util.py 1172 2007-03-09 20:34:37Z pronovic $
+# Revision : $Id: util.py 1232 2007-09-20 03:07:07Z pronovic $
 # Purpose  : Provides general-purpose utilities.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -43,7 +43,7 @@
 Provides general-purpose utilities. 
 
 @sort: AbsolutePathList, ObjectTypeList, RestrictedValueList, RegexMatchList,
-       _Vertex, DirectedGraph, PathResolverSingleton, 
+       RegexList, _Vertex, DirectedGraph, PathResolverSingleton, 
        sortDict, convertSize, getUidGid, changeOwnership, splitCommandLine,
        resolveCommand, executeCommand, calculateFileAge, encodePath, nullDevice,
        deriveDayOfWeek, isStartOfWeek, buildNormalizedPath, 
@@ -135,6 +135,14 @@ MTAB_FILE          = "/etc/mtab"
 MOUNT_COMMAND      = [ "mount", ]
 UMOUNT_COMMAND     = [ "umount", ]
 
+DEFAULT_LANGUAGE   = "C"
+LANG_VAR           = "LANG"
+LOCALE_VARS        = [ "LC_ADDRESS", "LC_ALL", "LC_COLLATE",
+                       "LC_CTYPE", "LC_IDENTIFICATION", 
+                       "LC_MEASUREMENT", "LC_MESSAGES", 
+                       "LC_MONETARY", "LC_NAME", "LC_NUMERIC",
+                       "LC_PAPER", "LC_TELEPHONE", "LC_TIME", ]
+
 
 ########################################################################
 # UnorderedList class definition
@@ -281,7 +289,7 @@ class AbsolutePathList(UnorderedList):
       @raise ValueError: If item is not an absolute path.
       """
       if not os.path.isabs(item):
-         raise ValueError("Item must be an absolute path.")
+         raise ValueError("Not an absolute path: [%s]" % item)
       list.append(self, encodePath(item))
 
    def insert(self, index, item):
@@ -290,7 +298,7 @@ class AbsolutePathList(UnorderedList):
       @raise ValueError: If item is not an absolute path.
       """
       if not os.path.isabs(item):
-         raise ValueError("Item must be an absolute path.")
+         raise ValueError("Not an absolute path: [%s]" % item)
       list.insert(self, index, encodePath(item))
 
    def extend(self, seq):
@@ -300,7 +308,7 @@ class AbsolutePathList(UnorderedList):
       """
       for item in seq:
          if not os.path.isabs(item):
-            raise ValueError("All items must be absolute paths.")
+            raise ValueError("Not an absolute path: [%s]" % item)
       for item in seq:
          list.append(self, encodePath(item))
 
@@ -389,12 +397,15 @@ class RestrictedContentList(UnorderedList):
    exceptions or other problems.
    """
    
-   def __init__(self, valuesList, valuesDescr):
+   def __init__(self, valuesList, valuesDescr, prefix=None):
       """
       Initializes a list restricted to containing certain values.
       @param valuesList: List of valid values.
       @param valuesDescr: Short string describing list of values.
+      @param prefix: Prefix to use in error messages (None results in prefix "Item")
       """
+      self.prefix = "Item"
+      if prefix is not None: self.prefix = prefix
       self.valuesList = valuesList
       self.valuesDescr = valuesDescr
 
@@ -404,7 +415,7 @@ class RestrictedContentList(UnorderedList):
       @raise ValueError: If item is not in the values list.
       """
       if item not in self.valuesList:
-         raise ValueError("Item must be one of values in %s." % self.valuesDescr)
+         raise ValueError("%s must be one of the values in %s." % (self.prefix, self.valuesDescr))
       list.append(self, item)
 
    def insert(self, index, item):
@@ -413,7 +424,7 @@ class RestrictedContentList(UnorderedList):
       @raise ValueError: If item is not in the values list.
       """
       if item not in self.valuesList:
-         raise ValueError("Item must be one of values in %s." % self.valuesDescr)
+         raise ValueError("%s must be one of the values in %s." % (self.prefix, self.valuesDescr))
       list.insert(self, index, item)
 
    def extend(self, seq):
@@ -423,7 +434,7 @@ class RestrictedContentList(UnorderedList):
       """
       for item in seq:
          if item not in self.valuesList:
-            raise ValueError("Item must be one of values in %s." % self.valuesDescr)
+            raise ValueError("%s must be one of the values in %s." % (self.prefix, self.valuesDescr))
       list.extend(self, seq)
 
 
@@ -450,12 +461,15 @@ class RegexMatchList(UnorderedList):
    likely get either TypeError or AttributeError exceptions as a result.
    """
    
-   def __init__(self, valuesRegex, emptyAllowed=True):
+   def __init__(self, valuesRegex, emptyAllowed=True, prefix=None):
       """
       Initializes a list restricted to containing certain values.
       @param valuesRegex: Regular expression that must be matched, as a string
       @param emptyAllowed: Indicates whether empty or None values are allowed.
+      @param prefix: Prefix to use in error messages (None results in prefix "Item")
       """
+      self.prefix = "Item"
+      if prefix is not None: self.prefix = prefix
       self.valuesRegex = valuesRegex
       self.emptyAllowed = emptyAllowed
       self.pattern = re.compile(self.valuesRegex)
@@ -468,9 +482,9 @@ class RegexMatchList(UnorderedList):
       @raise ValueError: If item does not match the configured regular expression
       """
       if item is None or (not self.emptyAllowed and item == ""):
-         raise ValueError("Item must be non-empty.")
+         raise ValueError("%s cannot be empty." % self.prefix)
       if not self.pattern.search(item):
-         raise ValueError("Item must match regular expression [%s]." % self.valuesRegex)
+         raise ValueError("%s is not valid: [%s]" % (self.prefix, item))
       list.append(self, item)
 
    def insert(self, index, item):
@@ -481,9 +495,9 @@ class RegexMatchList(UnorderedList):
       @raise ValueError: If item does not match the configured regular expression
       """
       if item is None or (not self.emptyAllowed and item == ""):
-         raise ValueError("Item must be non-empty.")
+         raise ValueError("%s cannot be empty." % self.prefix)
       if not self.pattern.search(item):
-         raise ValueError("Item must match regular expression [%s]." % self.valuesRegex)
+         raise ValueError("%s is not valid [%s]" % (self.prefix, item))
       list.insert(self, index, item)
 
    def extend(self, seq):
@@ -495,12 +509,63 @@ class RegexMatchList(UnorderedList):
       """
       for item in seq:
          if item is None or (not self.emptyAllowed and item == ""):
-            raise ValueError("Item must be non-empty.")
+            raise ValueError("%s cannot be empty.", self.prefix)
          if not self.pattern.search(item):
-            raise ValueError("Item must match regular expression [%s]." % self.valuesRegex)
+            raise ValueError("%s is not valid: [%s]" % (self.prefix, item))
       list.extend(self, seq)
 
 
+########################################################################
+# RegexList class definition
+########################################################################
+
+class RegexList(UnorderedList):
+
+   """
+   Class representing a list of valid regular expression strings.
+
+   This is an unordered list.
+
+   We override the C{append}, C{insert} and C{extend} methods to ensure that
+   any item added to the list is a valid regular expression.
+   """
+
+   def append(self, item):
+      """
+      Overrides the standard C{append} method.
+      @raise ValueError: If item is not an absolute path.
+      """
+      try:
+         re.compile(item)
+      except re.error:
+         raise ValueError("Not a valid regular expression: [%s]" % item)
+      list.append(self, item)
+
+   def insert(self, index, item):
+      """
+      Overrides the standard C{insert} method.
+      @raise ValueError: If item is not an absolute path.
+      """
+      try:
+         re.compile(item)
+      except re.error:
+         raise ValueError("Not a valid regular expression: [%s]" % item)
+      list.insert(self, index, item)
+
+   def extend(self, seq):
+      """
+      Overrides the standard C{insert} method.
+      @raise ValueError: If any item is not an absolute path.
+      """
+      for item in seq:
+         try:
+            re.compile(item)
+         except re.error:
+            raise ValueError("Not a valid regular expression: [%s]" % item)
+      for item in seq:
+         list.append(self, item)
+
+
 ########################################################################
 # Directed graph implementation
 ########################################################################
@@ -797,7 +862,7 @@ if _PIPE_IMPLEMENTATION == "subprocess.Popen":
 
       All of this functionality is provided (in Python 2.4 or later) by the
       C{subprocess.Popen} class, so when that class is available, we'll use it.
-      Otherwise, there's another implementation based on L{popen2.Popen4},
+      Otherwise, there's another implementation based on C{popen2.Popen4},
       which unfortunately only works on UNIX platforms.
       """
       def __init__(self, cmd, bufsize=-1, ignoreStderr=False):
@@ -1165,7 +1230,7 @@ def splitCommandLine(commandLine):
    @param commandLine: Command line string
    @type commandLine: String, i.e. "cback --verbose stage store"
 
-   @return: List of arguments, suitable for passing to L{popen2}.
+   @return: List of arguments, suitable for passing to C{popen2}.
 
    @raise ValueError: If the command line is None.
    """
@@ -1225,8 +1290,8 @@ def executeCommand(command, args, returnOutput=False, ignoreStderr=False, doNotL
    """
    Executes a shell command, hopefully in a safe way.
 
-   This function exists to replace direct calls to L{os.popen()} in the Cedar
-   Backup code.  It's not safe to call a function such as L{os.popen()} with
+   This function exists to replace direct calls to C{os.popen} in the Cedar
+   Backup code.  It's not safe to call a function such as C{os.popen()} with
    untrusted arguments, since that can cause problems if the string contains
    non-safe variables or other constructs (imagine that the argument is
    C{$WHATEVER}, but C{$WHATEVER} contains something like C{"; rm -fR ~/;
@@ -1238,7 +1303,7 @@ def executeCommand(command, args, returnOutput=False, ignoreStderr=False, doNotL
 
    Under the normal case, this function will return a tuple of C{(status,
    None)} where the status is the wait-encoded return status of the call per
-   the L{popen2.Popen4} documentation.  If C{returnOutput} is passed in as
+   the C{popen2.Popen4} documentation.  If C{returnOutput} is passed in as
    C{True}, the function will return a tuple of C{(status, output)} where
    C{output} is a list of strings, one entry per line in the output from the
    command.  Output is always logged to the C{outputLogger.info()} target,
@@ -1273,6 +1338,9 @@ def executeCommand(command, args, returnOutput=False, ignoreStderr=False, doNotL
    implement the equivalent to redirection using C{ignoreStderr} and
    C{outputFile}, as discussed above.
 
+   @note: The operating system environment is partially sanitized before
+   the command is invoked.  See L{sanitizeEnvironment} for details.
+
    @param command: Shell command to execute
    @type command: List of individual arguments that make up the command
 
@@ -1299,6 +1367,7 @@ def executeCommand(command, args, returnOutput=False, ignoreStderr=False, doNotL
    fields = command[:]        # make sure to copy it so we don't destroy it
    fields.extend(args)
    try:
+      sanitizeEnvironment()   # make sure we have a consistent environment
       pipe = Pipe(fields, ignoreStderr=ignoreStderr)
       while True:
          line = pipe.fromchild.readline()
@@ -1719,3 +1788,34 @@ def buildNormalizedPath(path):
       normalized = re.sub(r"\s", "_", normalized)  # convert all whitespace to '_'
       return normalized
 
+
+#################################
+# sanitizeEnvironment() function
+#################################
+
+def sanitizeEnvironment():
+   """
+   Sanitizes the operating system environment.
+   
+   The operating system environment is contained in C{os.environ}.  This method
+   sanitizes the contents of that dictionary.  
+
+   Currently, all it does is reset the locale (removing C{$LC_*}) and set the
+   default language (C{$LANG}) to L{DEFAULT_LANGUAGE}.  This way, we can count
+   on consistent localization regardless of what the end-user has configured.
+   This is important for code that needs to parse program output.
+
+   The C{os.environ} dictionary is modifed in-place.  If C{$LANG} is already
+   set to the proper value, it is not re-set, so we can avoid the memory leaks
+   that are documented to occur on BSD-based systems.
+
+   @return: Copy of the sanitized environment.
+   """
+   for var in LOCALE_VARS:
+      if os.environ.has_key(var):
+         del os.environ[var]
+   if os.environ.has_key(LANG_VAR):
+      if os.environ[LANG_VAR] != DEFAULT_LANGUAGE: # no need to reset if it exists (avoid leaks on BSD systems)
+         os.environ[LANG_VAR] = DEFAULT_LANGUAGE
+   return os.environ.copy()
+   
