@@ -30,7 +30,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.3)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: xmlutil.py 987 2006-06-24 19:26:26Z pronovic $
+# Revision : $Id: xmlutil.py 1181 2007-03-25 16:18:22Z pronovic $
 # Purpose  : Provides general XML-related functionality.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -245,6 +245,27 @@ def readInteger(parent, name):
    else:
       return int(result)
 
+def readFloat(parent, name):
+   """
+   Returns float contents of the first child with a given name immediately
+   beneath the parent.
+
+   By "immediately beneath" the parent, we mean from among nodes that are
+   direct children of the passed-in parent node.  
+
+   @param parent: Parent node to search beneath.
+   @param name: Name of node to search for.
+
+   @return: Float contents of node or C{None} if no matching nodes are found.
+   @raise ValueError: If the string at the location can't be converted to a
+   float value.
+   """
+   result = readString(parent, name)
+   if result is None:
+      return None
+   else:
+      return float(result)
+
 def readBoolean(parent, name):
    """
    Returns boolean contents of the first child with a given name immediately
