@@ -28,7 +28,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.3)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: mboxtests.py 1104 2007-02-17 16:51:19Z pronovic $
+# Revision : $Id: mboxtests.py 1210 2007-07-05 03:04:54Z pronovic $
 # Purpose  : Tests mbox extension functionality.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -656,6 +656,34 @@ class TestMboxDir(unittest.TestCase):
       mboxDir.excludePatterns.insert(1, "bogus")
       self.failUnlessEqual(["valid", "bogus", "more", ], mboxDir.excludePatterns)
 
+   def testConstructor_023(self):
+      """
+      Test assignment of excludePatterns attribute, single invalid entry.
+      """
+      mboxDir = MboxDir()
+      self.failUnlessEqual(None, mboxDir.excludePatterns)
+      self.failUnlessAssignRaises(ValueError, mboxDir, "excludePatterns", ["*.jpg", ])
+      self.failUnlessEqual(None, mboxDir.excludePatterns)
+
+   def testConstructor_024(self):
+      """
+      Test assignment of excludePatterns attribute, multiple invalid entries.
+      """
+      mboxDir = MboxDir()
+      self.failUnlessEqual(None, mboxDir.excludePatterns)
+      self.failUnlessAssignRaises(ValueError, mboxDir, "excludePatterns", ["*.jpg", "*" ])
+      self.failUnlessEqual(None, mboxDir.excludePatterns)
+
+   def testConstructor_025(self):
+      """
+      Test assignment of excludePatterns attribute, mixed valid and invalid
+      entries.
+      """
+      mboxDir = MboxDir()
+      self.failUnlessEqual(None, mboxDir.excludePatterns)
+      self.failUnlessAssignRaises(ValueError, mboxDir, "excludePatterns", ["*.jpg", "valid" ])
+      self.failUnlessEqual(None, mboxDir.excludePatterns)
+
 
    ############################
    # Test comparison operators
