@@ -28,7 +28,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.3)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: test.py 1137 2007-02-24 02:29:54Z pronovic $
+# Revision : $Id: test.py 1208 2007-07-05 02:09:00Z pronovic $
 # Purpose  : Run all of the unit tests for the project.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -197,7 +197,7 @@ def main():
    # Print a starting banner
    print "\n*** Running CedarBackup2 unit tests."
    if not full:
-      print "*** Using reduced feature set with minimum system requirements."
+      print "*** Using reduced feature set suite with minimum system requirements."
 
    # Make a list of tests to run
    unittests = { }
